/*
* Licensed to the Apache Software Foundation (ASF) under one or more
* contributor license agreements.  See the NOTICE file distributed with
* this work for additional information regarding copyright ownership.
* The ASF licenses this file to You under the Apache License, Version 2.0
* (the "License"); you may not use this file except in compliance with
* the License.  You may obtain a copy of the License at
*
*     http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/
package org.apache.poi.hssf.record.formula.functions;

import org.apache.poi.hssf.record.formula.eval.ErrorEval;
import org.apache.poi.hssf.record.formula.eval.Eval;
import org.apache.poi.hssf.record.formula.eval.EvaluationException;
import org.apache.poi.hssf.record.formula.eval.OperandResolver;
import org.apache.poi.hssf.record.formula.eval.StringEval;
import org.apache.poi.hssf.record.formula.eval.ValueEval;

/**
 * An implementation of the TRIM function:
 * Removes leading and trailing spaces from value if evaluated operand
 *  value is string.
 * @author Manda Wilson &lt; wilson at c bio dot msk cc dot org &gt;
 */
public final class Trim extends TextFunction {

	public Eval evaluate(Eval[] args, int srcCellRow, short srcCellCol) {
		
		if(args.length != 1) {
			return ErrorEval.VALUE_INVALID;
		}
		
		try {
			ValueEval veval = OperandResolver.getSingleValue(args[0], srcCellRow, srcCellCol);

			String str = OperandResolver.coerceValueToString(veval);
			str = str.trim();
			if(str.length() < 1) {
				return StringEval.EMPTY_INSTANCE;
			}
			return new StringEval(str);
		} catch (EvaluationException e) {
			return e.getErrorEval();
		}
	}
}
